@@ -1,7 +1,7 @@
 #ifndef exposemanifold 
 #define exposemanifold
 
-#include "scorematchingad.h"
+#include "scorematchingad_forward.h"
 #include "manifoldtransforms/manifolds.hpp"
 #include "manifoldtransforms/transforms.hpp"
 #include <Rcpp.h>
