@@ -1,7 +1,7 @@
 #ifndef tapebdryweight
 #define tapebdryweight
 
-# include "scorematchingad.h"
+# include "scorematchingad_forward.h"
 
 CppAD::ADFun<double> tapeh2(veca1 z,
                             a1type (*h2fun)(const veca1 &, const double &),
